"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.builds.build_pb2
import qwak.builds.build_url_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class BuildModelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_SPEC_FIELD_NUMBER: builtins.int
    @property
    def build_spec(self) -> qwak.builds.build_pb2.RemoteBuildSpec:
        """Requested build model spec"""
    def __init__(
        self,
        *,
        build_spec: qwak.builds.build_pb2.RemoteBuildSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["build_spec", b"build_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_spec", b"build_spec"]) -> None: ...

global___BuildModelRequest = BuildModelRequest

class BuildModelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___BuildModelResponse = BuildModelResponse

class CancelBuildModelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_ID_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    """Build id of the build to cancel"""
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id"]) -> None: ...

global___CancelBuildModelRequest = CancelBuildModelRequest

class CancelBuildModelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CancelBuildModelResponse = CancelBuildModelResponse

class CreateUploadURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_ID_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    """Model id"""
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id"]) -> None: ...

global___CreateUploadURLRequest = CreateUploadURLRequest

class CreateUploadURLResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPLOAD_URL_FIELD_NUMBER: builtins.int
    DOWNLOAD_URL_FIELD_NUMBER: builtins.int
    upload_url: builtins.str
    """Upload url intended for the model code upload"""
    download_url: builtins.str
    """URL which will contain the content uploaded to the upload url"""
    def __init__(
        self,
        *,
        upload_url: builtins.str = ...,
        download_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["download_url", b"download_url", "upload_url", b"upload_url"]) -> None: ...

global___CreateUploadURLResponse = CreateUploadURLResponse

class GetBuildVersioningUploadURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> qwak.builds.build_url_pb2.BuildVersioningUrlParams:
        """The params to define the url."""
    def __init__(
        self,
        *,
        params: qwak.builds.build_url_pb2.BuildVersioningUrlParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params"]) -> None: ...

global___GetBuildVersioningUploadURLRequest = GetBuildVersioningUploadURLRequest

class GetBuildVersioningUploadUrlsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.builds.build_url_pb2.BuildVersioningUrlParams]:
        """The params to define the url."""
    def __init__(
        self,
        *,
        params: collections.abc.Iterable[qwak.builds.build_url_pb2.BuildVersioningUrlParams] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params"]) -> None: ...

global___GetBuildVersioningUploadUrlsRequest = GetBuildVersioningUploadUrlsRequest

class GetBuildVersioningUploadURLResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class HeadersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    UPLOAD_URL_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    AUTHENTICATION_DETAIL_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    upload_url: builtins.str
    """Upload url intended for the upload"""
    path: builtins.str
    """The Path we saved the artifact in"""
    @property
    def authentication_detail(self) -> global___AuthenticationDetail:
        """Authentication detail for the upload url"""
    @property
    def headers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Headers to be used for the upload"""
    def __init__(
        self,
        *,
        upload_url: builtins.str = ...,
        path: builtins.str = ...,
        authentication_detail: global___AuthenticationDetail | None = ...,
        headers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authentication_detail", b"authentication_detail"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_detail", b"authentication_detail", "headers", b"headers", "path", b"path", "upload_url", b"upload_url"]) -> None: ...

global___GetBuildVersioningUploadURLResponse = GetBuildVersioningUploadURLResponse

class AuthenticationDetail(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JFROG_AUTHENTICATION_DETAIL_FIELD_NUMBER: builtins.int
    @property
    def jfrog_authentication_detail(self) -> global___JfrogAuthenticationDetail: ...
    def __init__(
        self,
        *,
        jfrog_authentication_detail: global___JfrogAuthenticationDetail | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["integration_type", b"integration_type", "jfrog_authentication_detail", b"jfrog_authentication_detail"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["integration_type", b"integration_type", "jfrog_authentication_detail", b"jfrog_authentication_detail"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["integration_type", b"integration_type"]) -> typing_extensions.Literal["jfrog_authentication_detail"] | None: ...

global___AuthenticationDetail = AuthenticationDetail

class GetBuildVersioningUploadUrlsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class UploadUrlInfosEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___UploadUrlInfo: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___UploadUrlInfo | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    UPLOAD_URL_INFOS_FIELD_NUMBER: builtins.int
    @property
    def upload_url_infos(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___UploadUrlInfo]:
        """Upload url intended for the upload"""
    def __init__(
        self,
        *,
        upload_url_infos: collections.abc.Mapping[builtins.str, global___UploadUrlInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["upload_url_infos", b"upload_url_infos"]) -> None: ...

global___GetBuildVersioningUploadUrlsResponse = GetBuildVersioningUploadUrlsResponse

class UploadUrlInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class HeadersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    UPLOAD_URL_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    upload_url: builtins.str
    """Upload url intended for the upload"""
    path: builtins.str
    """The Path we saved the artifact in"""
    @property
    def headers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Headers to be used for the upload"""
    def __init__(
        self,
        *,
        upload_url: builtins.str = ...,
        path: builtins.str = ...,
        headers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["headers", b"headers", "path", b"path", "upload_url", b"upload_url"]) -> None: ...

global___UploadUrlInfo = UploadUrlInfo

class JfrogAuthenticationDetail(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    username: builtins.str
    token: builtins.str
    def __init__(
        self,
        *,
        username: builtins.str = ...,
        token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["token", b"token", "username", b"username"]) -> None: ...

global___JfrogAuthenticationDetail = JfrogAuthenticationDetail

class GetBuildVersioningDownloadURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> qwak.builds.build_url_pb2.BuildVersioningUrlParams:
        """The params to define the url."""
    def __init__(
        self,
        *,
        params: qwak.builds.build_url_pb2.BuildVersioningUrlParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params"]) -> None: ...

global___GetBuildVersioningDownloadURLRequest = GetBuildVersioningDownloadURLRequest

class GetBuildVersioningDownloadUrLsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.builds.build_url_pb2.BuildVersioningUrlParams]:
        """The params to define the url."""
    def __init__(
        self,
        *,
        params: collections.abc.Iterable[qwak.builds.build_url_pb2.BuildVersioningUrlParams] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params"]) -> None: ...

global___GetBuildVersioningDownloadUrLsRequest = GetBuildVersioningDownloadUrLsRequest

class GetBuildVersioningDownloadURLResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class HeadersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DOWNLOAD_URL_FIELD_NUMBER: builtins.int
    FILE_SIZE_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    download_url: builtins.str
    """Download url - to download the wanted artifact."""
    file_size: builtins.int
    """The size of the file."""
    @property
    def headers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Headers to be used for the download"""
    def __init__(
        self,
        *,
        download_url: builtins.str = ...,
        file_size: builtins.int = ...,
        headers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["download_url", b"download_url", "file_size", b"file_size", "headers", b"headers"]) -> None: ...

global___GetBuildVersioningDownloadURLResponse = GetBuildVersioningDownloadURLResponse

class GetBuildVersioningDownloadUrlsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class DownloadUrlInfosEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___DownloadUrlInfo: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___DownloadUrlInfo | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DOWNLOAD_URL_INFOS_FIELD_NUMBER: builtins.int
    @property
    def download_url_infos(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___DownloadUrlInfo]: ...
    def __init__(
        self,
        *,
        download_url_infos: collections.abc.Mapping[builtins.str, global___DownloadUrlInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["download_url_infos", b"download_url_infos"]) -> None: ...

global___GetBuildVersioningDownloadUrlsResponse = GetBuildVersioningDownloadUrlsResponse

class DownloadUrlInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class HeadersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DOWNLOAD_URL_FIELD_NUMBER: builtins.int
    FILE_SIZE_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    download_url: builtins.str
    file_size: builtins.int
    """The size of the file."""
    @property
    def headers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        download_url: builtins.str = ...,
        file_size: builtins.int = ...,
        headers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["download_url", b"download_url", "file_size", b"file_size", "headers", b"headers"]) -> None: ...

global___DownloadUrlInfo = DownloadUrlInfo

class ListBuildVersioningTagsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_VERSIONING_TAGS_FIELD_NUMBER: builtins.int
    @property
    def build_versioning_tags(self) -> qwak.builds.build_url_pb2.BuildVersioningTags:
        """The params to define the urls."""
    def __init__(
        self,
        *,
        build_versioning_tags: qwak.builds.build_url_pb2.BuildVersioningTags | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["build_versioning_tags", b"build_versioning_tags"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_versioning_tags", b"build_versioning_tags"]) -> None: ...

global___ListBuildVersioningTagsRequest = ListBuildVersioningTagsRequest

class ListBuildVersioningTagsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_VERSIONING_TAGS_PROPERTIES_FIELD_NUMBER: builtins.int
    UI_DIRECT_LINK_FIELD_NUMBER: builtins.int
    @property
    def build_versioning_tags_properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.builds.build_url_pb2.BuildVersioningTagsProperties]:
        """Download urls - to download the wanted artifacts."""
    ui_direct_link: builtins.str
    """Direct build link"""
    def __init__(
        self,
        *,
        build_versioning_tags_properties: collections.abc.Iterable[qwak.builds.build_url_pb2.BuildVersioningTagsProperties] | None = ...,
        ui_direct_link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_versioning_tags_properties", b"build_versioning_tags_properties", "ui_direct_link", b"ui_direct_link"]) -> None: ...

global___ListBuildVersioningTagsResponse = ListBuildVersioningTagsResponse

class CreateDataTableRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    TABLE_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The model Id"""
    build_id: builtins.str
    """The build Id"""
    tag: builtins.str
    """The tag save data by."""
    @property
    def table(self) -> qwak.builds.build_pb2.DataTableDefinition:
        """Table Definition"""
    path: builtins.str
    """The path where the data is saved in"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        build_id: builtins.str = ...,
        tag: builtins.str = ...,
        table: qwak.builds.build_pb2.DataTableDefinition | None = ...,
        path: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["table", b"table"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id", "model_id", b"model_id", "path", b"path", "table", b"table", "tag", b"tag"]) -> None: ...

global___CreateDataTableRequest = CreateDataTableRequest

class CreateDataTableResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CreateDataTableResponse = CreateDataTableResponse

class GetBaseDockerImageNameRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_DOCKER_IMAGE_TYPE_FIELD_NUMBER: builtins.int
    base_docker_image_type: qwak.builds.build_pb2.BaseDockerImageType.ValueType
    def __init__(
        self,
        *,
        base_docker_image_type: qwak.builds.build_pb2.BaseDockerImageType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_docker_image_type", b"base_docker_image_type"]) -> None: ...

global___GetBaseDockerImageNameRequest = GetBaseDockerImageNameRequest

class GetBaseDockerImageNameResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_DOCKER_IMAGE_NAME_FIELD_NUMBER: builtins.int
    base_docker_image_name: builtins.str
    def __init__(
        self,
        *,
        base_docker_image_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_docker_image_name", b"base_docker_image_name"]) -> None: ...

global___GetBaseDockerImageNameResponse = GetBaseDockerImageNameResponse

class SaveArtifactPathRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARTIFACT_PATH_SPEC_FIELD_NUMBER: builtins.int
    @property
    def artifact_path_spec(self) -> qwak.builds.build_url_pb2.BuildArtifactPathSpec:
        """The artifact path specification"""
    def __init__(
        self,
        *,
        artifact_path_spec: qwak.builds.build_url_pb2.BuildArtifactPathSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["artifact_path_spec", b"artifact_path_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["artifact_path_spec", b"artifact_path_spec"]) -> None: ...

global___SaveArtifactPathRequest = SaveArtifactPathRequest

class SaveArtifactPathResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SaveArtifactPathResponse = SaveArtifactPathResponse

class ListBuildArtifactsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_ID_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    """The build Id to list the artifacts for"""
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id"]) -> None: ...

global___ListBuildArtifactsRequest = ListBuildArtifactsRequest

class ListBuildArtifactsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARTIFACTS_FIELD_NUMBER: builtins.int
    @property
    def artifacts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.builds.build_url_pb2.BuildArtifact]:
        """The build's artifacts"""
    def __init__(
        self,
        *,
        artifacts: collections.abc.Iterable[qwak.builds.build_url_pb2.BuildArtifact] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["artifacts", b"artifacts"]) -> None: ...

global___ListBuildArtifactsResponse = ListBuildArtifactsResponse

class DetachBuildsFromModelVersionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_VERSION_IDS_FIELD_NUMBER: builtins.int
    @property
    def model_version_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The model versions to detach"""
    def __init__(
        self,
        *,
        model_version_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_version_ids", b"model_version_ids"]) -> None: ...

global___DetachBuildsFromModelVersionsRequest = DetachBuildsFromModelVersionsRequest

class DetachBuildsFromModelVersionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DetachBuildsFromModelVersionsResponse = DetachBuildsFromModelVersionsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/admiral/secret/v0/secret_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.admiral.secret.v0 import secret_pb2 as qwak_dot_admiral_dot_secret_dot_v0_dot_secret__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+qwak/admiral/secret/v0/secret_service.proto\x12\x16qwak.admiral.secret.v0\x1a#qwak/admiral/secret/v0/secret.proto\"g\n\x1bSetEnvironmentSecretRequest\x12H\n\x07options\x18\x01 \x01(\x0b\x32\x37.qwak.admiral.secret.v0.SetUserEnvironmentSecretOptions\"\x1e\n\x1cSetEnvironmentSecretResponse\"i\n\x1e\x44\x65leteEnvironmentSecretRequest\x12G\n\nidentifier\x18\x01 \x01(\x0b\x32\x33.qwak.admiral.secret.v0.EnvironmentSecretIdentifier\"!\n\x1f\x44\x65leteEnvironmentSecretResponse\"\x1b\n\x19ListAccountSecretsRequest\"]\n\x1aListAccountSecretsResponse\x12?\n\x0f\x61\x63\x63ount_secrets\x18\x01 \x01(\x0b\x32&.qwak.admiral.secret.v0.AccountSecrets2\x9d\x03\n\rSecretService\x12\x81\x01\n\x14SetEnvironmentSecret\x12\x33.qwak.admiral.secret.v0.SetEnvironmentSecretRequest\x1a\x34.qwak.admiral.secret.v0.SetEnvironmentSecretResponse\x12\x8a\x01\n\x17\x44\x65leteEnvironmentSecret\x12\x36.qwak.admiral.secret.v0.DeleteEnvironmentSecretRequest\x1a\x37.qwak.admiral.secret.v0.DeleteEnvironmentSecretResponse\x12{\n\x12ListAccountSecrets\x12\x31.qwak.admiral.secret.v0.ListAccountSecretsRequest\x1a\x32.qwak.admiral.secret.v0.ListAccountSecretsResponseB\x8c\x01\n\x1d\x63om.qwak.ai.admiral.secret.v0P\x01Zigithub.com/qwak-ai/qwak-platform/services/core/go/admiral/admiral-api/pb/qwak/admiral/secret/v0;secret_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.admiral.secret.v0.secret_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.admiral.secret.v0P\001Zigithub.com/qwak-ai/qwak-platform/services/core/go/admiral/admiral-api/pb/qwak/admiral/secret/v0;secret_v0'
  _globals['_SETENVIRONMENTSECRETREQUEST']._serialized_start=108
  _globals['_SETENVIRONMENTSECRETREQUEST']._serialized_end=211
  _globals['_SETENVIRONMENTSECRETRESPONSE']._serialized_start=213
  _globals['_SETENVIRONMENTSECRETRESPONSE']._serialized_end=243
  _globals['_DELETEENVIRONMENTSECRETREQUEST']._serialized_start=245
  _globals['_DELETEENVIRONMENTSECRETREQUEST']._serialized_end=350
  _globals['_DELETEENVIRONMENTSECRETRESPONSE']._serialized_start=352
  _globals['_DELETEENVIRONMENTSECRETRESPONSE']._serialized_end=385
  _globals['_LISTACCOUNTSECRETSREQUEST']._serialized_start=387
  _globals['_LISTACCOUNTSECRETSREQUEST']._serialized_end=414
  _globals['_LISTACCOUNTSECRETSRESPONSE']._serialized_start=416
  _globals['_LISTACCOUNTSECRETSRESPONSE']._serialized_end=509
  _globals['_SECRETSERVICE']._serialized_start=512
  _globals['_SECRETSERVICE']._serialized_end=925
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/authenticated_user/v1/details.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7qwak/administration/authenticated_user/v1/details.proto\x12)qwak.administration.authenticated_user.v1\"/\n\x0bUserDetails\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\"|\n\x12\x45nvironmentDetails\x12\n\n\x02id\x18\x01 \x01(\t\x12Z\n\rconfiguration\x18\x02 \x01(\x0b\x32\x43.qwak.administration.authenticated_user.v1.EnvironmentConfiguration\"\xa5\x02\n\x18\x45nvironmentConfiguration\x12\x19\n\x11\x65\x64ge_services_url\x18\x01 \x01(\t\x12\x1d\n\x15management_access_url\x18\x06 \x01(\t\x12\x15\n\rmodel_api_url\x18\x02 \x01(\t\x12\x1e\n\x16\x61nalytics_data_api_url\x18\x03 \x01(\t\x12\x1d\n\x15object_storage_bucket\x18\x04 \x01(\t\x12\x19\n\x11\x62i_system_api_key\x18\x05 \x01(\t\x12^\n\x13\x63loud_configuration\x18\x07 \x01(\x0b\x32\x41.qwak.administration.authenticated_user.v1.QwakCloudConfiguration\"\x8e\x01\n\x16QwakCloudConfiguration\x12\x63\n\x17\x61ws_cloud_configuration\x18\x01 \x01(\x0b\x32@.qwak.administration.authenticated_user.v1.AwsCloudConfigurationH\x00\x42\x0f\n\rconfiguration\"a\n\x15\x41wsCloudConfiguration\x12\x0e\n\x06region\x18\x01 \x01(\t\x12\x10\n\x08role_arn\x18\x02 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x03 \x01(\t\x12\x11\n\tworkgroup\x18\x04 \x01(\tBN\n4com.qwak.ai.administration.api.authenticated_user.v1P\x01Z\x14.;authenticated_userb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.authenticated_user.v1.details_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n4com.qwak.ai.administration.api.authenticated_user.v1P\001Z\024.;authenticated_user'
  _globals['_USERDETAILS']._serialized_start=102
  _globals['_USERDETAILS']._serialized_end=149
  _globals['_ENVIRONMENTDETAILS']._serialized_start=151
  _globals['_ENVIRONMENTDETAILS']._serialized_end=275
  _globals['_ENVIRONMENTCONFIGURATION']._serialized_start=278
  _globals['_ENVIRONMENTCONFIGURATION']._serialized_end=571
  _globals['_QWAKCLOUDCONFIGURATION']._serialized_start=574
  _globals['_QWAKCLOUDCONFIGURATION']._serialized_end=716
  _globals['_AWSCLOUDCONFIGURATION']._serialized_start=718
  _globals['_AWSCLOUDCONFIGURATION']._serialized_end=815
# @@protoc_insertion_point(module_scope)



from abc import ABC, abstractmethod
from dataclasses import dataclass
from typing import Dict

from qwak.llmops.prompt.value import PromptValue, StringPromptValue


@dataclass
class BasePromptTemplate(ABC):
    @abstractmethod
    def render(self, variables: Dict[str, any]) -> PromptValue:
        pass


@dataclass
class StringPromptTemplate(BasePromptTemplate):
    template: str

    def render(self, variables: Dict[str, any]) -> StringPromptValue:
        from chevron import renderer

        return StringPromptValue(
            text=renderer.render(template=self.template, data=variables, warn=True)
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/admiral/user_application_instance/v0/user_application_instance.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.v0.environments import environment_pb2 as qwak_dot_administration_dot_v0_dot_environments_dot_environment__pb2
from _qwak_proto.qwak.user_application.v0 import user_application_pb2 as qwak_dot_user__application_dot_v0_dot_user__application__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nIqwak/admiral/user_application_instance/v0/user_application_instance.proto\x12!qwak.admiral.user_app_instance.v0\x1a\x35qwak/administration/v0/environments/environment.proto\x1a/qwak/user_application/v0/user_application.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf0\x01\n\rCreateOptions\x12\x41\n\nidentifier\x18\x01 \x01(\x0b\x32-.qwak.admiral.user_app_instance.v0.Identifier\x12\x18\n\x10kind_sem_version\x18\x03 \x01(\t\x12,\n\x04spec\x18\x04 \x01(\x0b\x32\x1e.qwak.user_application.v0.Spec\x12T\n\x14resource_reservation\x18\x05 \x01(\x0b\x32\x36.qwak.admiral.user_app_instance.v0.ResourceReservation\"\xc5\x04\n\x11UpdateSpecOptions\x12\x41\n\nidentifier\x18\x01 \x01(\x0b\x32-.qwak.admiral.user_app_instance.v0.Identifier\x12,\n\x04spec\x18\x02 \x01(\x0b\x32\x1e.qwak.user_application.v0.Spec\x12T\n\x14resource_reservation\x18\x04 \x01(\x0b\x32\x36.qwak.admiral.user_app_instance.v0.ResourceReservation\x12T\n\x14revision_restriction\x18\x05 \x01(\x0b\x32\x36.qwak.admiral.user_app_instance.v0.RevisionRestriction\x12\x62\n\x1bkind_version_update_options\x18\x06 \x01(\x0b\x32;.qwak.admiral.user_app_instance.v0.KindVersionUpdateOptionsH\x00\x12x\n#static_global_config_update_options\x18\x07 \x01(\x0b\x32I.qwak.admiral.user_app_instance.v0.StaticGlobalConfigurationUpdateOptionsH\x01\x42\x19\n\x17kind_version_update_optB\x1a\n\x18static_global_update_opt\";\n\x13ResourceReservation\x12\x11\n\tcpu_cores\x18\x01 \x01(\x02\x12\x11\n\tmemory_mb\x18\x02 \x01(\r\"\xec\x01\n\x0b\x44\x65scription\x12=\n\x08metadata\x18\x01 \x01(\x0b\x32+.qwak.admiral.user_app_instance.v0.Metadata\x12L\n\x10spec_description\x18\x02 \x01(\x0b\x32\x32.qwak.admiral.user_app_instance.v0.SpecDescription\x12P\n\x12status_description\x18\x03 \x01(\x0b\x32\x34.qwak.admiral.user_app_instance.v0.StatusDescription\"\x95\x01\n\x0fSpecDescription\x12,\n\x04spec\x18\x01 \x01(\x0b\x32\x1e.qwak.user_application.v0.Spec\x12T\n\x14static_configuration\x18\x02 \x01(\x0b\x32\x36.qwak.admiral.user_app_instance.v0.GlobalConfiguration\"E\n\x11StatusDescription\x12\x30\n\x06status\x18\x01 \x01(\x0b\x32 .qwak.user_application.v0.Status\"\xa6\x03\n\x08Metadata\x12\x41\n\nidentifier\x18\x01 \x01(\x0b\x32-.qwak.admiral.user_app_instance.v0.Identifier\x12\x14\n\x0ckind_version\x18\x02 \x01(\t\x12\x35\n\x11spec_last_updated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x13status_last_updated\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncluster_id\x18\x06 \x01(\t\x12\x0c\n\x04uuid\x18\x08 \x01(\t\x12#\n\x1blast_deployed_spec_revision\x18\x07 \x01(\x04\x12\x15\n\rspec_revision\x18\t \x01(\x04\x12\x17\n\x0fstatus_revision\x18\n \x01(\x04\x12*\n\"environment_sequencer_when_changed\x18\x0b \x01(\x04\"t\n\nIdentifier\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12,\n\x04type\x18\x02 \x01(\x0e\x32\x1e.qwak.user_application.v0.Type\x12\x16\n\x0e\x65nvironment_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"J\n\x13RevisionRestriction\x12\x1f\n\x15\x63urrent_spec_revision\x18\x01 \x01(\x04H\x00\x42\x12\n\x10restriction_type\"\\\n\x13GlobalConfiguration\x12\x45\n\x0b\x65nvironment\x18\x01 \x01(\x0b\x32\x30.qwak.administration.environment.QwakEnvironment\"\xb4\x02\n\x18KindVersionUpdateOptions\x12[\n\x15keep_existing_version\x18\x01 \x01(\x0b\x32:.qwak.admiral.user_app_instance.v0.KeepExistingKindVersionH\x00\x12S\n\x13latest_kind_version\x18\x02 \x01(\x0b\x32\x34.qwak.admiral.user_app_instance.v0.LatestKindVersionH\x00\x12W\n\x15\x65xplicit_kind_version\x18\x03 \x01(\x0b\x32\x36.qwak.admiral.user_app_instance.v0.ExplicitKindVersionH\x00\x42\r\n\x0bupdate_type\"\x19\n\x17KeepExistingKindVersion\"\x13\n\x11LatestKindVersion\"+\n\x13\x45xplicitKindVersion\x12\x14\n\x0ckind_version\x18\x01 \x01(\t\"\xaa\x02\n&StaticGlobalConfigurationUpdateOptions\x12}\n)keep_existing_static_global_configuration\x18\x01 \x01(\x0b\x32H.qwak.admiral.user_app_instance.v0.KeepExistingStaticGlobalConfigurationH\x00\x12r\n#refresh_static_global_configuration\x18\x02 \x01(\x0b\x32\x43.qwak.admiral.user_app_instance.v0.RefreshStaticGlobalConfigurationH\x00\x42\r\n\x0bupdate_type\"\'\n%KeepExistingStaticGlobalConfiguration\"\"\n RefreshStaticGlobalConfigurationB\xbe\x01\n(com.qwak.ai.admiral.user_app_instance.v0P\x01Z\x8f\x01github.com/qwak-ai/qwak-platform/services/core/go/admiral/admiral-api/pb/qwak/admiral/user_application_instance/v0;user_application_instance_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.admiral.user_application_instance.v0.user_application_instance_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.qwak.ai.admiral.user_app_instance.v0P\001Z\217\001github.com/qwak-ai/qwak-platform/services/core/go/admiral/admiral-api/pb/qwak/admiral/user_application_instance/v0;user_application_instance_v0'
  _globals['_CREATEOPTIONS']._serialized_start=250
  _globals['_CREATEOPTIONS']._serialized_end=490
  _globals['_UPDATESPECOPTIONS']._serialized_start=493
  _globals['_UPDATESPECOPTIONS']._serialized_end=1074
  _globals['_RESOURCERESERVATION']._serialized_start=1076
  _globals['_RESOURCERESERVATION']._serialized_end=1135
  _globals['_DESCRIPTION']._serialized_start=1138
  _globals['_DESCRIPTION']._serialized_end=1374
  _globals['_SPECDESCRIPTION']._serialized_start=1377
  _globals['_SPECDESCRIPTION']._serialized_end=1526
  _globals['_STATUSDESCRIPTION']._serialized_start=1528
  _globals['_STATUSDESCRIPTION']._serialized_end=1597
  _globals['_METADATA']._serialized_start=1600
  _globals['_METADATA']._serialized_end=2022
  _globals['_IDENTIFIER']._serialized_start=2024
  _globals['_IDENTIFIER']._serialized_end=2140
  _globals['_REVISIONRESTRICTION']._serialized_start=2142
  _globals['_REVISIONRESTRICTION']._serialized_end=2216
  _globals['_GLOBALCONFIGURATION']._serialized_start=2218
  _globals['_GLOBALCONFIGURATION']._serialized_end=2310
  _globals['_KINDVERSIONUPDATEOPTIONS']._serialized_start=2313
  _globals['_KINDVERSIONUPDATEOPTIONS']._serialized_end=2621
  _globals['_KEEPEXISTINGKINDVERSION']._serialized_start=2623
  _globals['_KEEPEXISTINGKINDVERSION']._serialized_end=2648
  _globals['_LATESTKINDVERSION']._serialized_start=2650
  _globals['_LATESTKINDVERSION']._serialized_end=2669
  _globals['_EXPLICITKINDVERSION']._serialized_start=2671
  _globals['_EXPLICITKINDVERSION']._serialized_end=2714
  _globals['_STATICGLOBALCONFIGURATIONUPDATEOPTIONS']._serialized_start=2717
  _globals['_STATICGLOBALCONFIGURATIONUPDATEOPTIONS']._serialized_end=3015
  _globals['_KEEPEXISTINGSTATICGLOBALCONFIGURATION']._serialized_start=3017
  _globals['_KEEPEXISTINGSTATICGLOBALCONFIGURATION']._serialized_end=3056
  _globals['_REFRESHSTATICGLOBALCONFIGURATION']._serialized_start=3058
  _globals['_REFRESHSTATICGLOBALCONFIGURATION']._serialized_end=3092
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.administration.runtime_configuration.v0.container_registry_config_pb2
import qwak.administration.runtime_configuration.v0.data_catalog_config_pb2
import qwak.administration.runtime_configuration.v0.feature_store_config_pb2
import qwak.administration.runtime_configuration.v0.hosting_config_pb2
import qwak.administration.runtime_configuration.v0.logs_storage_config_pb2
import qwak.administration.runtime_configuration.v0.model_analytics_storage_config_pb2
import qwak.administration.runtime_configuration.v0.object_storage_config_pb2
import qwak.administration.runtime_configuration.v0.observability_config_pb2
import qwak.administration.runtime_configuration.v0.sql_engine_config_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class RuntimeConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOSTING_CONFIGURATION_FIELD_NUMBER: builtins.int
    FEATURE_STORE_CONFIGURATION_FIELD_NUMBER: builtins.int
    OBJECT_STORAGE_CONFIGURATION_FIELD_NUMBER: builtins.int
    LOGS_STORAGE_CONFIGURATION_FIELD_NUMBER: builtins.int
    DATA_CATALOG_CONFIGURATION_FIELD_NUMBER: builtins.int
    SQL_ENGINE_CONFIGURATION_FIELD_NUMBER: builtins.int
    MODEL_ANALYTICS_STORAGE_CONFIGURATION_FIELD_NUMBER: builtins.int
    OBSERVABILITY_CONFIGURATION_FIELD_NUMBER: builtins.int
    CONTAINER_REGISTRY_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def hosting_configuration(self) -> qwak.administration.runtime_configuration.v0.hosting_config_pb2.HostingConfiguration: ...
    @property
    def feature_store_configuration(self) -> qwak.administration.runtime_configuration.v0.feature_store_config_pb2.FeatureStoreConfiguration: ...
    @property
    def object_storage_configuration(self) -> qwak.administration.runtime_configuration.v0.object_storage_config_pb2.ObjectStorageConfiguration: ...
    @property
    def logs_storage_configuration(self) -> qwak.administration.runtime_configuration.v0.logs_storage_config_pb2.LogsStorageConfiguration: ...
    @property
    def data_catalog_configuration(self) -> qwak.administration.runtime_configuration.v0.data_catalog_config_pb2.DataCatalogConfiguration: ...
    @property
    def sql_engine_configuration(self) -> qwak.administration.runtime_configuration.v0.sql_engine_config_pb2.SqlEngineConfiguration: ...
    @property
    def model_analytics_storage_configuration(self) -> qwak.administration.runtime_configuration.v0.model_analytics_storage_config_pb2.ModelAnalyticsStorageConfiguration: ...
    @property
    def observability_configuration(self) -> qwak.administration.runtime_configuration.v0.observability_config_pb2.ObservabilityConfiguration: ...
    @property
    def container_registry_configuration(self) -> qwak.administration.runtime_configuration.v0.container_registry_config_pb2.ContainerRegistryConfiguration: ...
    def __init__(
        self,
        *,
        hosting_configuration: qwak.administration.runtime_configuration.v0.hosting_config_pb2.HostingConfiguration | None = ...,
        feature_store_configuration: qwak.administration.runtime_configuration.v0.feature_store_config_pb2.FeatureStoreConfiguration | None = ...,
        object_storage_configuration: qwak.administration.runtime_configuration.v0.object_storage_config_pb2.ObjectStorageConfiguration | None = ...,
        logs_storage_configuration: qwak.administration.runtime_configuration.v0.logs_storage_config_pb2.LogsStorageConfiguration | None = ...,
        data_catalog_configuration: qwak.administration.runtime_configuration.v0.data_catalog_config_pb2.DataCatalogConfiguration | None = ...,
        sql_engine_configuration: qwak.administration.runtime_configuration.v0.sql_engine_config_pb2.SqlEngineConfiguration | None = ...,
        model_analytics_storage_configuration: qwak.administration.runtime_configuration.v0.model_analytics_storage_config_pb2.ModelAnalyticsStorageConfiguration | None = ...,
        observability_configuration: qwak.administration.runtime_configuration.v0.observability_config_pb2.ObservabilityConfiguration | None = ...,
        container_registry_configuration: qwak.administration.runtime_configuration.v0.container_registry_config_pb2.ContainerRegistryConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["container_registry_configuration", b"container_registry_configuration", "data_catalog_configuration", b"data_catalog_configuration", "feature_store_configuration", b"feature_store_configuration", "hosting_configuration", b"hosting_configuration", "logs_storage_configuration", b"logs_storage_configuration", "model_analytics_storage_configuration", b"model_analytics_storage_configuration", "object_storage_configuration", b"object_storage_configuration", "observability_configuration", b"observability_configuration", "sql_engine_configuration", b"sql_engine_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_registry_configuration", b"container_registry_configuration", "data_catalog_configuration", b"data_catalog_configuration", "feature_store_configuration", b"feature_store_configuration", "hosting_configuration", b"hosting_configuration", "logs_storage_configuration", b"logs_storage_configuration", "model_analytics_storage_configuration", b"model_analytics_storage_configuration", "object_storage_configuration", b"object_storage_configuration", "observability_configuration", b"observability_configuration", "sql_engine_configuration", b"sql_engine_configuration"]) -> None: ...

global___RuntimeConfiguration = RuntimeConfiguration



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/sources/data_source_attribute.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.feature_store.v1.common.source_code import source_code_pb2 as qwak_dot_feature__store_dot_v1_dot_common_dot_source__code_dot_source__code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6qwak/feature_store/sources/data_source_attribute.proto\x12\x1aqwak.feature.store.sources\x1a:qwak/feature_store/v1/common/source_code/source_code.proto\"j\n\x14\x44\x61taSourceAttributes\x12R\n\x10source_code_spec\x18\x01 \x01(\x0b\x32\x38.qwak.feature.store.v1.common.source_code.SourceCodeSpecBX\n%com.qwak.ai.feature.store.sources.apiP\x01Z-qwak/featurestore/sources;featurestoresourcesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.sources.data_source_attribute_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.feature.store.sources.apiP\001Z-qwak/featurestore/sources;featurestoresources'
  _globals['_DATASOURCEATTRIBUTES']._serialized_start=146
  _globals['_DATASOURCEATTRIBUTES']._serialized_end=252
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/backfill.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.feature_store.features import execution_pb2 as qwak_dot_feature__store_dot_features_dot_execution__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n qwak/execution/v1/backfill.proto\x12\x1fqwak.feature.store.execution.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a+qwak/feature_store/features/execution.proto\"\xb2\x04\n\x0c\x42\x61\x63kfillSpec\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\x12T\n\x11interval_backfill\x18\x02 \x01(\x0b\x32\x37.qwak.feature.store.execution.v1.IntervalBackfillWindowH\x00\x12W\n\x13\x66ull_reset_backfill\x18\x03 \x01(\x0b\x32\x38.qwak.feature.store.execution.v1.FullResetBackfillWindowH\x00\x12\x0f\n\x07\x63omment\x18\x05 \x01(\t\x12\x44\n\rbackfill_type\x18\x06 \x01(\x0b\x32-.qwak.feature.store.execution.v1.BackfillType\x12U\n\x0bno_override\x18\x07 \x01(\x0b\x32>.qwak.feature.store.execution.v1.ImplicitResourceConfigurationH\x01\x12`\n\x16\x65xplicit_configuration\x18\x08 \x01(\x0b\x32>.qwak.feature.store.execution.v1.ExplicitResourceConfigurationH\x01\x12\x13\n\x0b\x62\x61\x63kfill_id\x18\t \x01(\tB\x16\n\x14\x62\x61\x63kfill_window_typeB\x1d\n\x1bresource_configuration_type\"\x1f\n\x1dImplicitResourceConfiguration\"\x8b\x01\n\x1d\x45xplicitResourceConfiguration\x12R\n\x10\x63luster_template\x18\x01 \x01(\x0e\x32\x36.qwak.feature.store.features.execution.ClusterTemplateH\x00\x42\x16\n\x14resource_config_type\"q\n\x0c\x42\x61\x63kfillType\x12P\n\x0c\x61s_scheduled\x18\x01 \x01(\x0b\x32\x38.qwak.feature.store.execution.v1.AsScheduledBackfillTypeH\x00\x42\x0f\n\rbackfill_type\"\x19\n\x17\x41sScheduledBackfillType\"~\n\x16IntervalBackfillWindow\x12\x32\n\x0e\x62\x61\x63kfill_start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x62\x61\x63kfill_end\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x19\n\x17\x46ullResetBackfillWindowB)\n%com.qwak.ai.features.execution.api.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.execution.v1.backfill_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.features.execution.api.v1P\001'
  _globals['_BACKFILLSPEC']._serialized_start=148
  _globals['_BACKFILLSPEC']._serialized_end=710
  _globals['_IMPLICITRESOURCECONFIGURATION']._serialized_start=712
  _globals['_IMPLICITRESOURCECONFIGURATION']._serialized_end=743
  _globals['_EXPLICITRESOURCECONFIGURATION']._serialized_start=746
  _globals['_EXPLICITRESOURCECONFIGURATION']._serialized_end=885
  _globals['_BACKFILLTYPE']._serialized_start=887
  _globals['_BACKFILLTYPE']._serialized_end=1000
  _globals['_ASSCHEDULEDBACKFILLTYPE']._serialized_start=1002
  _globals['_ASSCHEDULEDBACKFILLTYPE']._serialized_end=1027
  _globals['_INTERVALBACKFILLWINDOW']._serialized_start=1029
  _globals['_INTERVALBACKFILLWINDOW']._serialized_end=1155
  _globals['_FULLRESETBACKFILLWINDOW']._serialized_start=1157
  _globals['_FULLRESETBACKFILLWINDOW']._serialized_end=1182
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.administration.runtime_configuration.v0.creds.secret_pb2
import qwak.administration.runtime_configuration.v0.hosting.aws.auth_pb2
import qwak.administration.runtime_configuration.v0.hosting.azure.auth_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class HostingConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AWS_HOST_CONFIGURATION_FIELD_NUMBER: builtins.int
    GCP_HOST_CONFIGURATION_FIELD_NUMBER: builtins.int
    AZURE_HOST_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def aws_host_configuration(self) -> global___AWSHostingConfiguration: ...
    @property
    def gcp_host_configuration(self) -> global___GCPHostingConfiguration: ...
    @property
    def azure_host_configuration(self) -> global___AzureHostingConfiguration: ...
    def __init__(
        self,
        *,
        aws_host_configuration: global___AWSHostingConfiguration | None = ...,
        gcp_host_configuration: global___GCPHostingConfiguration | None = ...,
        azure_host_configuration: global___AzureHostingConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws_host_configuration", b"aws_host_configuration", "azure_host_configuration", b"azure_host_configuration", "gcp_host_configuration", b"gcp_host_configuration", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_host_configuration", b"aws_host_configuration", "azure_host_configuration", b"azure_host_configuration", "gcp_host_configuration", b"gcp_host_configuration", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["aws_host_configuration", "gcp_host_configuration", "azure_host_configuration"] | None: ...

global___HostingConfiguration = HostingConfiguration

class AWSHostingConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IAM_SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    SCOPED_PERMISSIONS_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    @property
    def iam_service_account(self) -> global___IAMServiceAccount: ...
    @property
    def scoped_permissions(self) -> qwak.administration.runtime_configuration.v0.hosting.aws.auth_pb2.AWSScopedPermissions: ...
    region: builtins.str
    def __init__(
        self,
        *,
        iam_service_account: global___IAMServiceAccount | None = ...,
        scoped_permissions: qwak.administration.runtime_configuration.v0.hosting.aws.auth_pb2.AWSScopedPermissions | None = ...,
        region: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "iam_service_account", b"iam_service_account", "scoped_permissions", b"scoped_permissions"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "iam_service_account", b"iam_service_account", "region", b"region", "scoped_permissions", b"scoped_permissions"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth", b"auth"]) -> typing_extensions.Literal["iam_service_account", "scoped_permissions"] | None: ...

global___AWSHostingConfiguration = AWSHostingConfiguration

class GCPHostingConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GCP_SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    @property
    def gcp_service_account(self) -> global___GCPServiceAccountAuth: ...
    region: builtins.str
    project_id: builtins.str
    def __init__(
        self,
        *,
        gcp_service_account: global___GCPServiceAccountAuth | None = ...,
        region: builtins.str = ...,
        project_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "gcp_service_account", b"gcp_service_account"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "gcp_service_account", b"gcp_service_account", "project_id", b"project_id", "region", b"region"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth", b"auth"]) -> typing_extensions.Literal["gcp_service_account"] | None: ...

global___GCPHostingConfiguration = GCPHostingConfiguration

class GCPServiceAccountAuth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_JSON_FIELD_NUMBER: builtins.int
    @property
    def service_account(self) -> global___IAMServiceAccount: ...
    @property
    def service_account_json(self) -> qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef: ...
    def __init__(
        self,
        *,
        service_account: global___IAMServiceAccount | None = ...,
        service_account_json: qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["service_account", b"service_account", "service_account_json", b"service_account_json"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["service_account", b"service_account", "service_account_json", b"service_account_json"]) -> None: ...

global___GCPServiceAccountAuth = GCPServiceAccountAuth

class IAMServiceAccount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLE_NAME_FIELD_NUMBER: builtins.int
    role_name: builtins.str
    def __init__(
        self,
        *,
        role_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["role_name", b"role_name"]) -> None: ...

global___IAMServiceAccount = IAMServiceAccount

class AzureHostingConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AZURE_AUTH_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    AZURE_TENANT_ID_FIELD_NUMBER: builtins.int
    @property
    def azure_auth(self) -> qwak.administration.runtime_configuration.v0.hosting.azure.auth_pb2.AzureAuthentication: ...
    region: builtins.str
    azure_tenant_id: builtins.str
    def __init__(
        self,
        *,
        azure_auth: qwak.administration.runtime_configuration.v0.hosting.azure.auth_pb2.AzureAuthentication | None = ...,
        region: builtins.str = ...,
        azure_tenant_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["azure_auth", b"azure_auth"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["azure_auth", b"azure_auth", "azure_tenant_id", b"azure_tenant_id", "region", b"region"]) -> None: ...

global___AzureHostingConfiguration = AzureHostingConfiguration



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/features/feature_set_state.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3qwak/feature_store/features/feature_set_state.proto\x12\x1bqwak.feature.store.features\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9e\x03\n\x0f\x46\x65\x61tureSetState\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x02 \x01(\t\x12R\n\x0fspark_app_state\x18\x03 \x01(\x0e\x32\x39.qwak.feature.store.features.FeatureSetLastExecutionState\x12\x44\n\x0f\x65xecutor_states\x18\x04 \x01(\x0b\x32+.qwak.feature.store.features.ExecutorStates\x12L\n\x14\x66\x65\x61ture_set_job_type\x18\x05 \x01(\x0b\x32..qwak.feature.store.features.FeatureSetJobType\x12\x15\n\rerror_message\x18\x06 \x01(\t\x12\x14\n\x0cspark_app_id\x18\x07 \x01(\t\x12\x34\n\x10last_modified_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06run_id\x18\t \x01(\x03\"\xac\x02\n\x11\x46\x65\x61tureSetJobType\x12;\n\tstreaming\x18\x01 \x01(\x0b\x32&.qwak.feature.store.features.StreamingH\x00\x12\x38\n\x08\x62\x61tch_v1\x18\x02 \x01(\x0b\x32$.qwak.feature.store.features.BatchV1H\x00\x12R\n\x15streaming_aggregation\x18\x03 \x01(\x0b\x32\x31.qwak.feature.store.features.StreamingAggregationH\x00\x12@\n\x0c\x64\x65letion_job\x18\x04 \x01(\x0b\x32(.qwak.feature.store.features.DeletionJobH\x00\x42\n\n\x08job_type\"\x87\x01\n\tStreaming\x12\x35\n\x06online\x18\x01 \x01(\x0b\x32#.qwak.feature.store.features.OnlineH\x00\x12\x37\n\x07offline\x18\x02 \x01(\x0b\x32$.qwak.feature.store.features.OfflineH\x00\x42\n\n\x08sub_type\"\x08\n\x06Online\"\t\n\x07Offline\"\t\n\x07\x42\x61tchV1\"\xdf\x01\n\x14StreamingAggregation\x12:\n\trow_level\x18\x01 \x01(\x0b\x32%.qwak.feature.store.features.RowLevelH\x00\x12@\n\x08\x62\x61\x63kfill\x18\x02 \x01(\x0b\x32,.qwak.feature.store.features.BackfillSubTypeH\x00\x12=\n\ncompaction\x18\x03 \x01(\x0b\x32\'.qwak.feature.store.features.CompactionH\x00\x42\n\n\x08sub_type\"\n\n\x08RowLevel\"\x0c\n\nCompaction\"\x11\n\x0f\x42\x61\x63kfillSubType\"\xbe\x02\n\x0b\x44\x65letionJob\x12S\n\x11\x62\x61tch_v1_deletion\x18\x01 \x01(\x0b\x32\x36.qwak.feature.store.features.BatchV1DeletionJobSubTypeH\x00\x12[\n\x15streaming_v1_deletion\x18\x02 \x01(\x0b\x32:.qwak.feature.store.features.StreamingV1DeletionJobSubTypeH\x00\x12m\n\x1estreaming_aggregation_deletion\x18\x03 \x01(\x0b\x32\x43.qwak.feature.store.features.StreamingAggregationDeletionJobSubTypeH\x00\x42\x0e\n\x0cjob_sub_type\"\x1b\n\x19\x42\x61tchV1DeletionJobSubType\"\x1f\n\x1dStreamingV1DeletionJobSubType\"(\n&StreamingAggregationDeletionJobSubType\"U\n\x0e\x45xecutorStates\x12\x43\n\x0f\x65xecutor_states\x18\x01 \x03(\x0b\x32*.qwak.feature.store.features.ExecutorState\"p\n\rExecutorState\x12\x15\n\rexecutor_name\x18\x01 \x01(\t\x12H\n\x05state\x18\x02 \x01(\x0e\x32\x39.qwak.feature.store.features.FeatureSetLastExecutionState*\xd5\x01\n\x1c\x46\x65\x61tureSetLastExecutionState\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x46\x41ILED\x10\x01\x12\x0b\n\x07SUCCESS\x10\x02\x12\x10\n\x0cINVALIDATING\x10\x03\x12\r\n\tSUBMITTED\x10\x04\x12\x0b\n\x07RUNNING\x10\x05\x12\r\n\tCOMPLETED\x10\x06\x12\x15\n\x11SUBMISSION_FAILED\x10\x07\x12\x11\n\rPENDING_RERUN\x10\x08\x12\x0e\n\nSUCCEEDING\x10\t\x12\x0b\n\x07\x46\x41ILING\x10\n\x12\x0b\n\x07PENDING\x10\x0b\x42[\n&com.qwak.ai.feature.store.features.apiP\x01Z/qwak/featurestore/features;featurestorefeaturesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.features.feature_set_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.feature.store.features.apiP\001Z/qwak/featurestore/features;featurestorefeatures'
  _globals['_FEATURESETLASTEXECUTIONSTATE']._serialized_start=1905
  _globals['_FEATURESETLASTEXECUTIONSTATE']._serialized_end=2118
  _globals['_FEATURESETSTATE']._serialized_start=118
  _globals['_FEATURESETSTATE']._serialized_end=532
  _globals['_FEATURESETJOBTYPE']._serialized_start=535
  _globals['_FEATURESETJOBTYPE']._serialized_end=835
  _globals['_STREAMING']._serialized_start=838
  _globals['_STREAMING']._serialized_end=973
  _globals['_ONLINE']._serialized_start=975
  _globals['_ONLINE']._serialized_end=983
  _globals['_OFFLINE']._serialized_start=985
  _globals['_OFFLINE']._serialized_end=994
  _globals['_BATCHV1']._serialized_start=996
  _globals['_BATCHV1']._serialized_end=1005
  _globals['_STREAMINGAGGREGATION']._serialized_start=1008
  _globals['_STREAMINGAGGREGATION']._serialized_end=1231
  _globals['_ROWLEVEL']._serialized_start=1233
  _globals['_ROWLEVEL']._serialized_end=1243
  _globals['_COMPACTION']._serialized_start=1245
  _globals['_COMPACTION']._serialized_end=1257
  _globals['_BACKFILLSUBTYPE']._serialized_start=1259
  _globals['_BACKFILLSUBTYPE']._serialized_end=1276
  _globals['_DELETIONJOB']._serialized_start=1279
  _globals['_DELETIONJOB']._serialized_end=1597
  _globals['_BATCHV1DELETIONJOBSUBTYPE']._serialized_start=1599
  _globals['_BATCHV1DELETIONJOBSUBTYPE']._serialized_end=1626
  _globals['_STREAMINGV1DELETIONJOBSUBTYPE']._serialized_start=1628
  _globals['_STREAMINGV1DELETIONJOBSUBTYPE']._serialized_end=1659
  _globals['_STREAMINGAGGREGATIONDELETIONJOBSUBTYPE']._serialized_start=1661
  _globals['_STREAMINGAGGREGATIONDELETIONJOBSUBTYPE']._serialized_end=1701
  _globals['_EXECUTORSTATES']._serialized_start=1703
  _globals['_EXECUTORSTATES']._serialized_end=1788
  _globals['_EXECUTORSTATE']._serialized_start=1790
  _globals['_EXECUTORSTATE']._serialized_end=1902
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/streaming.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!qwak/execution/v1/streaming.proto\x12\x1fqwak.feature.store.execution.v1\"3\n\x18OnlineStreamingIngestion\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\"\xfe\x01\n\x19OfflineStreamingIngestion\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\x12^\n\x11scheduled_trigger\x18\x02 \x01(\x0b\x32\x41.qwak.feature.store.execution.v1.ScheduledOfflineStreamingTriggerH\x00\x12X\n\x0emanual_trigger\x18\x03 \x01(\x0b\x32>.qwak.feature.store.execution.v1.ManualOfflineStreamingTriggerH\x00\x42\x0e\n\x0ctrigger_type\"\"\n ScheduledOfflineStreamingTrigger\"\x1f\n\x1dManualOfflineStreamingTriggerB)\n%com.qwak.ai.features.execution.api.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.execution.v1.streaming_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.features.execution.api.v1P\001'
  _globals['_ONLINESTREAMINGINGESTION']._serialized_start=70
  _globals['_ONLINESTREAMINGINGESTION']._serialized_end=121
  _globals['_OFFLINESTREAMINGINGESTION']._serialized_start=124
  _globals['_OFFLINESTREAMINGINGESTION']._serialized_end=378
  _globals['_SCHEDULEDOFFLINESTREAMINGTRIGGER']._serialized_start=380
  _globals['_SCHEDULEDOFFLINESTREAMINGTRIGGER']._serialized_end=414
  _globals['_MANUALOFFLINESTREAMINGTRIGGER']._serialized_start=416
  _globals['_MANUALOFFLINESTREAMINGTRIGGER']._serialized_end=447
# @@protoc_insertion_point(module_scope)



import uuid
from typing import Dict

import grpc
from _qwak_proto.qwak.models.models_pb2 import (
    CreateModelRequest,
    CreateModelResponse,
    DeleteModelRequest,
    DeleteModelResponse,
    GetModelMetadataResponse,
    GetModelRequest,
    GetModelResponse,
    ListModelsMetadataResponse,
    ListModelsResponse,
    Model,
    ModelMetadata,
    ModelSpec,
    ModelStatus,
)
from _qwak_proto.qwak.models.models_pb2_grpc import ModelsManagementServiceServicer
from qwak_services_mock.mocks.utils.exception_handlers import raise_internal_grpc_error


class ModelsManagementServiceMock(ModelsManagementServiceServicer):
    def __init__(self):
        super(ModelsManagementServiceMock, self).__init__()
        self.models: Dict[str, Model] = dict()
        self.models_by_uuid: Dict[str, Model] = dict()

    def CreateModel(self, request: CreateModelRequest, context) -> CreateModelResponse:
        try:
            formatted_model_id = request.model_spec.model_named_id.lower().replace(
                "-", "_"
            )
            created_model = self.model_spec_to_model(
                request.model_spec, formatted_model_id
            )

            self.models[formatted_model_id] = created_model
            self.models_by_uuid[created_model.uuid] = created_model

            return CreateModelResponse(model_id=formatted_model_id)
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def GetModel(self, request: GetModelRequest, context) -> GetModelResponse:
        try:
            if request.model_id:
                if request.model_id not in self.models:
                    context.set_code(grpc.StatusCode.NOT_FOUND)
                    details = f"Model id {request.model_id} not found"
                    context.set_details(details)
                    raise grpc.RpcError(details)
                else:
                    model: Model = self.models[request.model_id]
            else:
                if request.model_uuid not in self.models_by_uuid:
                    context.set_code(grpc.StatusCode.NOT_FOUND)
                    details = f"Model uuid {request.model_uuid} not found"
                    context.set_details(details)
                    raise grpc.RpcError(details)
                else:
                    model: Model = self.models_by_uuid[request.model_uuid]

            return GetModelResponse(model=model)
        except grpc.RpcError as e:
            raise e
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def DeleteModel(self, request: DeleteModelRequest, context) -> DeleteModelResponse:
        try:
            del self.models[request.model_id]
            return DeleteModelResponse()
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def GetModelMetadata(self, request, context):
        try:
            if request.model_id == "throw_exception":
                raise Exception("This is a test exception")
            model = self.models[request.model_id]
            return GetModelMetadataResponse(model_metadata=ModelMetadata(model=model))
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def ListModels(self, request, context):
        models = [
            model
            for _, model in self.models.items()
            if model.project_id == request.project_id
        ]
        return ListModelsResponse(models=models)

    def ListModelsMetadata(self, request, context):
        models = [
            ModelMetadata(model=model)
            for _, model in self.models.items()
            if model.project_id == request.project_id
        ]
        return ListModelsMetadataResponse(model_metadata=models)

    @staticmethod
    def model_spec_to_model(model_spec: ModelSpec, formatted_model_id: str):
        return Model(
            model_id=formatted_model_id,
            display_name=model_spec.display_name,
            model_status=ModelStatus.ACTIVE,
            model_description=model_spec.model_description,
            project_id=model_spec.project_id,
            uuid=str(uuid.uuid4()),
        )



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _UnaryOperatorType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _UnaryOperatorTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_UnaryOperatorType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNARY_OPERATOR_TYPE_INVALID: _UnaryOperatorType.ValueType  # 0
    UNARY_OPERATOR_TYPE_EXACT_MATCH: _UnaryOperatorType.ValueType  # 1
    UNARY_OPERATOR_TYPE_SAFE_REGEX_MATCH: _UnaryOperatorType.ValueType  # 2
    UNARY_OPERATOR_TYPE_PRESENT_MATCH: _UnaryOperatorType.ValueType  # 3
    UNARY_OPERATOR_TYPE_PREFIX_MATCH: _UnaryOperatorType.ValueType  # 4
    UNARY_OPERATOR_TYPE_SUFFIX_MATCH: _UnaryOperatorType.ValueType  # 5
    UNARY_OPERATOR_TYPE_CONTAINS_MATCH: _UnaryOperatorType.ValueType  # 6
    UNARY_OPERATOR_TYPE_STRING_MATCH: _UnaryOperatorType.ValueType  # 7

class UnaryOperatorType(_UnaryOperatorType, metaclass=_UnaryOperatorTypeEnumTypeWrapper):
    """Unary operators available types"""

UNARY_OPERATOR_TYPE_INVALID: UnaryOperatorType.ValueType  # 0
UNARY_OPERATOR_TYPE_EXACT_MATCH: UnaryOperatorType.ValueType  # 1
UNARY_OPERATOR_TYPE_SAFE_REGEX_MATCH: UnaryOperatorType.ValueType  # 2
UNARY_OPERATOR_TYPE_PRESENT_MATCH: UnaryOperatorType.ValueType  # 3
UNARY_OPERATOR_TYPE_PREFIX_MATCH: UnaryOperatorType.ValueType  # 4
UNARY_OPERATOR_TYPE_SUFFIX_MATCH: UnaryOperatorType.ValueType  # 5
UNARY_OPERATOR_TYPE_CONTAINS_MATCH: UnaryOperatorType.ValueType  # 6
UNARY_OPERATOR_TYPE_STRING_MATCH: UnaryOperatorType.ValueType  # 7
global___UnaryOperatorType = UnaryOperatorType

class _BinaryOperatorType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BinaryOperatorTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BinaryOperatorType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BINARY_OPERATOR_TYPE_INVALID: _BinaryOperatorType.ValueType  # 0
    BINARY_OPERATOR_TYPE_RANGE_MATCH: _BinaryOperatorType.ValueType  # 1

class BinaryOperatorType(_BinaryOperatorType, metaclass=_BinaryOperatorTypeEnumTypeWrapper):
    """Binary operators available types"""

BINARY_OPERATOR_TYPE_INVALID: BinaryOperatorType.ValueType  # 0
BINARY_OPERATOR_TYPE_RANGE_MATCH: BinaryOperatorType.ValueType  # 1
global___BinaryOperatorType = BinaryOperatorType

class MultipleHttpTraffic(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_TRAFFICS_FIELD_NUMBER: builtins.int
    @property
    def http_traffics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HttpTraffic]: ...
    def __init__(
        self,
        *,
        http_traffics: collections.abc.Iterable[global___HttpTraffic] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["http_traffics", b"http_traffics"]) -> None: ...

global___MultipleHttpTraffic = MultipleHttpTraffic

class HttpTraffic(google.protobuf.message.Message):
    """Http traffic configuration"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ROUTE_MATCH_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    GROUP_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Id that will be used to modify the config by core services"""
    @property
    def route_match(self) -> global___RouteMatch: ...
    order: builtins.int
    """order"""
    group_id: builtins.str
    """owner of the traffic."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        route_match: global___RouteMatch | None = ...,
        order: builtins.int = ...,
        group_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["http_traffic", b"http_traffic", "route_match", b"route_match"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["group_id", b"group_id", "http_traffic", b"http_traffic", "id", b"id", "order", b"order", "route_match", b"route_match"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["http_traffic", b"http_traffic"]) -> typing_extensions.Literal["route_match"] | None: ...

global___HttpTraffic = HttpTraffic

class RouteMatch(google.protobuf.message.Message):
    """Route that base on match of rules"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    MATCHES_FIELD_NUMBER: builtins.int
    ROUTES_FIELD_NUMBER: builtins.int
    path: builtins.str
    """URL path to match for exampel /v1/predict/path"""
    @property
    def matches(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Match]:
        """Matches which should evaluate"""
    @property
    def routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Route]:
        """Route that will apply incase that all matches evaluated to true"""
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        matches: collections.abc.Iterable[global___Match] | None = ...,
        routes: collections.abc.Iterable[global___Route] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["matches", b"matches", "path", b"path", "routes", b"routes"]) -> None: ...

global___RouteMatch = RouteMatch

class Match(google.protobuf.message.Message):
    """Match rule"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_MATCH_FIELD_NUMBER: builtins.int
    @property
    def header_match(self) -> global___HeaderMatch: ...
    def __init__(
        self,
        *,
        header_match: global___HeaderMatch | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["header_match", b"header_match", "rule", b"rule"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_match", b"header_match", "rule", b"rule"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["rule", b"rule"]) -> typing_extensions.Literal["header_match"] | None: ...

global___Match = Match

class HeaderMatch(google.protobuf.message.Message):
    """Header match rule"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    INVERT_FIELD_NUMBER: builtins.int
    key: builtins.str
    """Header key"""
    @property
    def condition(self) -> global___HeaderCondition:
        """Header condition"""
    invert: builtins.bool
    """Condition evaluation should be inverted (For example False will be True)"""
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        condition: global___HeaderCondition | None = ...,
        invert: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "invert", b"invert", "key", b"key"]) -> None: ...

global___HeaderMatch = HeaderMatch

class HeaderCondition(google.protobuf.message.Message):
    """Header condition type - Unary/Binary condition"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BINARY_CONDITION_FIELD_NUMBER: builtins.int
    UNARY_CONDITION_FIELD_NUMBER: builtins.int
    @property
    def binary_condition(self) -> global___HeaderBinaryCondition: ...
    @property
    def unary_condition(self) -> global___HeaderUnaryCondition: ...
    def __init__(
        self,
        *,
        binary_condition: global___HeaderBinaryCondition | None = ...,
        unary_condition: global___HeaderUnaryCondition | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["binary_condition", b"binary_condition", "condition", b"condition", "unary_condition", b"unary_condition"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["binary_condition", b"binary_condition", "condition", b"condition", "unary_condition", b"unary_condition"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["condition", b"condition"]) -> typing_extensions.Literal["binary_condition", "unary_condition"] | None: ...

global___HeaderCondition = HeaderCondition

class HeaderUnaryCondition(google.protobuf.message.Message):
    """Unary condition definition
    For example: unary_operator UnaryOperator.UNARY_OPERATOR_EXACT_MATCH with operand hello,
                 will check that header value will be exactly hello.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATOR_FIELD_NUMBER: builtins.int
    OPERAND_FIELD_NUMBER: builtins.int
    operator: global___UnaryOperatorType.ValueType
    operand: builtins.str
    def __init__(
        self,
        *,
        operator: global___UnaryOperatorType.ValueType = ...,
        operand: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["operand", b"operand", "operator", b"operator"]) -> None: ...

global___HeaderUnaryCondition = HeaderUnaryCondition

class HeaderBinaryCondition(google.protobuf.message.Message):
    """Binary condition definition
    For example: unary_operator BinaryOperatorType.BINARY_OPERATOR_TYPE_RANGE_MATCH with first_operand 1,
                 and second operand 3 will check that header value will be in range of 1-3 included)
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATOR_FIELD_NUMBER: builtins.int
    FIRST_OPERAND_FIELD_NUMBER: builtins.int
    SECOND_OPERAND_FIELD_NUMBER: builtins.int
    operator: global___BinaryOperatorType.ValueType
    first_operand: builtins.str
    second_operand: builtins.str
    def __init__(
        self,
        *,
        operator: global___BinaryOperatorType.ValueType = ...,
        first_operand: builtins.str = ...,
        second_operand: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["first_operand", b"first_operand", "operator", b"operator", "second_operand", b"second_operand"]) -> None: ...

global___HeaderBinaryCondition = HeaderBinaryCondition

class Route(google.protobuf.message.Message):
    """Route configuration to apply on specific endpoint if all conditions evaluated to true."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENDPOINT_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    SHADOW_FIELD_NUMBER: builtins.int
    VARIATION_FIELD_NUMBER: builtins.int
    REQUEST_TIMEOUT_MS_FIELD_NUMBER: builtins.int
    endpoint: builtins.str
    """Endpoint weight"""
    weight: builtins.int
    """Weight of endpoint on splitting between other endpoints (Not percentage)"""
    shadow: builtins.bool
    """Shadow all traffic to this endpoint (All response from this endpoint will be ignored)"""
    variation: builtins.str
    """The variation of the specific endpoint"""
    request_timeout_ms: builtins.int
    """Timeout of the request in ms"""
    def __init__(
        self,
        *,
        endpoint: builtins.str = ...,
        weight: builtins.int = ...,
        shadow: builtins.bool = ...,
        variation: builtins.str = ...,
        request_timeout_ms: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoint", b"endpoint", "request_timeout_ms", b"request_timeout_ms", "shadow", b"shadow", "variation", b"variation", "weight", b"weight"]) -> None: ...

global___Route = Route



from typing import Optional

from qwak.clients.administration.eco_system.client import EcosystemClient
from qwak.exceptions import QwakException


def get_endpoint_url(
    endpoint_url: Optional[str] = None, environment_id: Optional[str] = None
) -> str:
    if not endpoint_url:
        user_context = EcosystemClient().get_authenticated_user_context().user
        if not environment_id:
            environment_id = user_context.account_details.default_environment_id

        if environment_id not in user_context.account_details.environment_by_id:
            raise QwakException(
                f"Configuration for environment '{environment_id}' was not found"
            )

        endpoint_url = user_context.account_details.environment_by_id[
            environment_id
        ].configuration.edge_services_url

    return endpoint_url
